/**
 * Creates JavaScript Date instances which let you work with dates and times.
 * @param {Number} milliseconds Integer value representing the number of milliseconds since 1 January 1970 00:00:00 UTC (Unix Epoch).
 * @param {String} dateString String value representing a date. The string should be in a format recognized by the parse method (IETF-compliant RFC 2822 timestamps).
 * @param {Number} year Integer value representing the year. For compatibility (in order to avoid the Y2K problem), you should always specify the year in full; use 1998, rather than 98.
 * @param {Number} month Integer value representing the month, beginning with 0 for January to 11 for December.
 * @param {Number} day Integer value representing the day of the month (1-31).
 * @param {Number} hour Integer value representing the hour of the day (0-23).
 * @param {Number} minute Integer value representing the minute segment (0-59) of a time reading.
 * @param {Number} second Integer value representing the second segment (0-59) of a time reading.
 * @param {Number} millisecond Integer value representing the millisecond segment (0-999) of a time reading.
 * @returns {Date} 
 */
function Date() {
    this.prototype
}
/**
 * Converts a date to a string, returning the "date" portion using the operating system's locale's conventions.
 * @syntax <code>toLocaleDateString()</code>
 * @returns {String} 
 */
Date.prototype.toLocaleDateString = function() {};

/**
 * Returns the seconds in the specified date according to universal time.
 * @syntax <code>getUTCSeconds()</code>
 * @returns {Number} 
 */
Date.prototype.getUTCSeconds = function() {};

/**
 * Sets the year for a specified date according to local time.
 * @syntax <code>setYear(<i>yearValue</i>)</code>
 * @param {Number} yearValue  An integer.
 * @returns {Number} 
 */
Date.prototype.setYear = function() {};

/**
 * Converts a date to a string, using the universal time convention.
 * @syntax <code>toUTCString()</code>
 * @returns {String} 
 */
Date.prototype.toUTCString = function() {};

/**
 * Sets the full year for a specified date according to universal time.
 * @syntax <code>setUTCFullYear(<em>yearValue</em>[,<em>monthValue</em>[,<em>dayValue</em>]])</code>
 * @param {Number} yearValue  An integer specifying the numeric value of the year, for example, 1995.
 * @param {Number} monthValue  An integer between 0 and 11 representing the months January through December.
 * @param {Number} dayValue  An integer between 1 and 31 representing the day of the month. If you specify the dayValue parameter, you must also specify the monthValue.
 * @returns {Number} 
 */
Date.prototype.setUTCFullYear = function() {};

/**
 * Returns the time-zone offset from UTC, in minutes, for the current locale.
 * @syntax <code>getTimezoneOffset()</code>
 * @returns {Number} 
 */
Date.prototype.getTimezoneOffset = function() {};

/**
 * Returns the day of the week for the specified date according to local time.
 * @syntax <code>getDay()</code>
 * @returns {Number} 
 */
Date.prototype.getDay = function() {};

/**
 * Sets the hour for a specified date according to universal time.
 * @syntax <code>setUTCHours(<em>hoursValue</em>[,<em>minutesValue</em>[,<em>secondsValue</em>[,<em>msValue</em>]]])</code>
 * @param {Number} hoursValue  An integer between 0 and 23, representing the hour.
 * @param {Number} minutesValue  An integer between 0 and 59, representing the minutes.
 * @param {Number} secondsValue  An integer between 0 and 59, representing the seconds. If you specify the secondsValue parameter, you must also specify the minutesValue.
 * @param {Number} msValue  A number between 0 and 999, representing the milliseconds. If you specify the msValue parameter, you must also specify the minutesValue and secondsValue.
 * @returns {Number} 
 */
Date.prototype.setUTCHours = function() {};

/**
 * Returns the year in the specified date according to local time.
 * @syntax <code>getYear()</code>
 * @returns {Number} 
 */
Date.prototype.getYear = function() {};

/**
 * Represents the prototype for the Date constructor.
 * @returns {Number} 
 * @static
 */
Date.prototype;

/**
 * Sets the minutes for a specified date according to local time.
 * @syntax <code>setMinutes(<i>minutesValue</i>[,<i>secondsValue</i>[,<em>msValue</em>]])</code>
<code>setMinutes(<i>minutesValue</i>)</code>
 * @param {Number} minutesValue  An integer between 0 and 59, representing the minutes.
 * @param {Number} secondsValue  An integer between 0 and 59, representing the seconds. If you specify the secondsValue parameter, you must also specify the minutesValue.
 * @param {Number} msValue  A number between 0 and 999, representing the milliseconds. If you specify the msValue parameter, you must also specify the minutesValue and secondsValue.
 * @returns {Number} 
 */
Date.prototype.setMinutes = function() {};

/**
 * JavaScript provides a direct way to convert a date object into a string in ISO format, the ISO 8601 Extended Format. The Date.prototype.toISOString is an ECMAScript 5 addition. Format is as follows: YYYY-MM-DDTHH:mm:ss.sssZ
 * @syntax <code>myDate.toISOString()</code>
 * @returns {String} 
 */
Date.prototype.toISOString = function() {};

/**
 * Sets the milliseconds for a specified date according to local time.
 * @syntax <code>setMilliseconds(<em>millisecondsValue</em>)</code>
 * @param {Number} millisecondsValue  A number between 0 and 999, representing the milliseconds.
 * @returns {Number} 
 */
Date.prototype.setMilliseconds = function() {};

/**
 * Accepts the same parameters as the longest form of the constructor, and returns the number of milliseconds in a Date object since January 1, 1970, 00:00:00, universal time.
 * @syntax <code>Date.UTC(<i>year</i>,<i>month</i>[,<i>date</i>[,<i>hrs</i>[,<i>min</i>[,<i>sec</i>[,<em>ms</em>]]]]])</code>
 * @param {String} year  A year after 1900.
 * @param {Number} month  An integer between 0 and 11 representing the month.
 * @param {Number} date  An integer between 1 and 31 representing the day of the month.
 * @param {Number} hrs  An integer between 0 and 23 representing the hours.
 * @param {Number} min  An integer between 0 and 59 representing the minutes.
 * @param {Number} sec  An integer between 0 and 59 representing the seconds.
 * @param {Number} ms  An integer between 0 and 999 representing the milliseconds.
 * @returns {Number} 
 * @static
 */
Date.UTC = function() {};

/**
 * Returns the day (date) of the month in the specified date according to universal time.
 * @syntax <code>getUTCDate()</code>
 * @returns {Number} 
 */
Date.prototype.getUTCDate = function() {};

/**
 * @syntax <code><em>date</em>.toTimeString()</code>
 * @returns {String} 
 */
Date.prototype.toTimeString = function() {};

/**
 * Sets the seconds for a specified date according to local time.
 * @syntax <code>setSeconds(<i>secondsValue</i>[,<em>msValue</em>])</code>
<code>setSeconds(<i>secondsValue</i>)</code>
 * @param {Number} secondsValue  An integer between 0 and 59.
 * @param {Number} msValue  A number between 0 and 999, representing the milliseconds.
 * @returns {Number} 
 */
Date.prototype.setSeconds = function() {};

/**
 * Sets the seconds for a specified date according to universal time.
 * @syntax <code>setUTCSeconds(<em>secondsValue</em>[,<em>msValue</em>])</code>
 * @param {Number} secondsValue  An integer between 0 and 59.
 * @param {Number} msValue  A number between 0 and 999, representing the milliseconds.
 * @returns {Number} 
 */
Date.prototype.setUTCSeconds = function() {};

/**
 * Returns the date portion of a Date object in human readable form in American English.
 * @syntax <code><em>date</em>.toDateString()</code>
 * @returns {String} 
 */
Date.prototype.toDateString = function() {};

/**
 * Returns the day of the month for the specified date according to local time.
 * @syntax <code>getDate()</code>
 * @returns {Number} 
 */
Date.prototype.getDate = function() {};

/**
 * Sets the hours for a specified date according to local time.
 * @syntax <code>setHours(<i>hoursValue</i>[,<i>minutesValue</i>[,<i>secondsValue</i>[,<em>msValue</em>]]])</code>
<code>setHours(<i>hoursValue</i>)</code>
 * @param {Number} hoursValue  An integer between 0 and 23, representing the hour.
 * @param {Number} minutesValue  An integer between 0 and 59, representing the minutes.
 * @param {Number} secondsValue  An integer between 0 and 59, representing the seconds. If you specify the secondsValue parameter, you must also specify the minutesValue.
 * @param {Number} msValue  A number between 0 and 999, representing the milliseconds. If you specify the msValue parameter, you must also specify the minutesValue and secondsValue.
 * @returns {Number} 
 */
Date.prototype.setHours = function() {};

/**
 * @returns {Number} 
 * @static
 */
Date.now = function() {};

/**
 * Returns the year in the specified date according to universal time.
 * @syntax <code>getUTCFullYear()</code>
 * @returns {Number} 
 */
Date.prototype.getUTCFullYear = function() {};

/**
 * Returns the month in the specified date according to local time.
 * @syntax <code>getMonth()</code>
 * @returns {Number} 
 */
Date.prototype.getMonth = function() {};

/**
 * Returns a string representing the specified Date object.
 * @syntax <code>toString()</code>
 * @returns {String} 
 */
Date.prototype.toString = function() {};

/**
 * Sets the day of the month for a specified date according to universal time.
 * @syntax <code>setUTCDate(<em>dayValue</em>)</code>
 * @param {Number} dayValue  An integer from 1 to 31, representing the day of the month.
 * @returns {Number} 
 */
Date.prototype.setUTCDate = function() {};

/**
 * Sets the month for a specified date according to universal time.
 * @syntax <code>setUTCMonth(<em>monthValue</em>[,<em>dayValue</em>])</code>
 * @param {Number} monthValue  An integer between 0 and 11, representing the months January through December.
 * @param {Number} dayValue  An integer from 1 to 31, representing the day of the month.
 * @returns {Number} 
 */
Date.prototype.setUTCMonth = function() {};

/**
 * Returns the minutes in the specified date according to local time.
 * @syntax <code>getMinutes()</code>
 * @returns {Number} 
 */
Date.prototype.getMinutes = function() {};

/**
 * Converts a date to a string, using the operating system's locale's conventions.
 * @syntax <code>toLocaleString()</code>
 * @returns {String} 
 */
Date.prototype.toLocaleString = function() {};

/**
 * Returns a string representing the source code of the object.
 * @syntax <code><em>date</em>.toSource()</code>
 * @returns {String} 
 */
Date.prototype.toSource = function() {};

/**
 * Returns the seconds in the specified date according to local time.
 * @syntax <code>getSeconds()</code>
 * @returns {Number} 
 */
Date.prototype.getSeconds = function() {};

/**
 * Returns the month of the specified date according to universal time.
 * @syntax <code>getUTCMonth()</code>
 * @returns {Number} 
 */
Date.prototype.getUTCMonth = function() {};

/**
 * Returns the year of the specified date according to local time.
 * @syntax <code>getFullYear()</code>
 * @returns {Number} 
 */
Date.prototype.getFullYear = function() {};

/**
 * Returns the hour for the specified date according to local time.
 * @syntax <code>getHours()</code>
 * @returns {Number} 
 */
Date.prototype.getHours = function() {};

/**
 * Returns the hours in the specified date according to universal time.
 * @syntax <code>getUTCHours</code>
 * @returns {Number} 
 */
Date.prototype.getUTCHours = function() {};

/**
 * Converts a date to a string using the specified formatting.
 * @param {String} formatString  A format string in the same format expected by the strftime() function in C.
 * @returns {Number} 
 */
Date.prototype.toLocaleFormat = function() {};

/**
 * Returns the primitive value of a Date object.
 * @syntax <code>valueOf()</code>
 * @returns {Number} 
 */
Date.prototype.valueOf = function() {};

/**
 * Parses a string representation of a date, and returns the number of milliseconds since January 1, 1970, 00:00:00 UTC.
 * @syntax <code>Date.parse(dateString)</code>
 * @param {String} dateString A string representing an RFC2822 or ISO 8601 date.
 * @returns {Number} 
 * @static
 */
Date.parse = function() {};

/**
 * Returns a reference to the Date function that created the instance's prototype. Note that the value of this property is a reference to the function itself, not a string containing the function's name.
 * @returns {Function} 
 */
Date.prototype.constructor;

/**
 * Sets the Date object to the time represented by a number of milliseconds since January 1, 1970, 00:00:00 UTC.
 * @syntax <code>setTime(<em>timeValue</em>)</code>
 * @param {Number} timeValue  An integer representing the number of milliseconds since 1 January 1970, 00:00:00 UTC.
 * @returns {Number} 
 */
Date.prototype.setTime = function() {};

/**
 * Converts a date to a string, returning the "time" portion using the current locale's conventions.
 * @syntax <code>toLocaleTimeString()</code>
 * @returns {String} 
 */
Date.prototype.toLocaleTimeString = function() {};

/**
 * Sets the milliseconds for a specified date according to universal time.
 * @syntax <code>setUTCMilliseconds(<em>millisecondsValue</em>)</code>
 * @param {Number} millisecondsValue  A number between 0 and 999, representing the milliseconds.
 * @returns {Number} 
 */
Date.prototype.setUTCMilliseconds = function() {};

/**
 * Sets the minutes for a specified date according to universal time.
 * @syntax <code>setUTCMinutes(<em>minutesValue</em>[,<em>secondsValue</em>[,<em>msValue</em>]])</code>
 * @param {Number} minutesValue  An integer between 0 and 59, representing the minutes.
 * @param {Number} secondsValue  An integer between 0 and 59, representing the seconds. If you specify the secondsValue parameter, you must also specify the minutesValue.
 * @param {Number} msValue  A number between 0 and 999, representing the milliseconds. If you specify the msValue parameter, you must also specify the minutesValue and secondsValue.
 * @returns {Number} 
 */
Date.prototype.setUTCMinutes = function() {};

/**
 * Set the month for a specified date according to local time.
 * @syntax <code>setMonth(<i>monthValue</i>[,<em>dayValue</em>])</code>
<code>setMonth(<i>monthValue</i>)</code>
 * @returns {Number} 
 */
Date.prototype.setMonth = function() {};

/**
 * Sets the day of the month for a specified date according to local time.
 * @syntax <code>setDate(<em>dayValue</em>)</code>
 * @param {Number} dayValue  An integer from 1 to 31, representing the day of the month.
 * @returns {Number} 
 */
Date.prototype.setDate = function() {};

/**
 * Returns the minutes in the specified date according to universal time.
 * @syntax <code>getUTCMinutes()</code>
 * @returns {Number} 
 */
Date.prototype.getUTCMinutes = function() {};

/**
 * Sets the full year for a specified date according to local time.
 * @syntax <code>setFullYear(<em>yearValue</em>[,<em>monthValue</em>[,<em>dayValue</em>]])</code>
 * @param {Number} yearValue  An integer specifying the numeric value of the year, for example, 1995.
 * @param {Number} monthValue  An integer between 0 and 11 representing the months January through December.
 * @param {Number} dayValue  An integer between 1 and 31 representing the day of the month. If you specify the dayValue parameter, you must also specify the monthValue.
 * @returns {Number} 
 */
Date.prototype.setFullYear = function() {};

/**
 * Returns the numeric value corresponding to the time for the specified date according to universal time.
 * @syntax <code>getTime()</code>
 * @returns {Number} 
 */
Date.prototype.getTime = function() {};

/**
 * Returns a JSON representation of the Date object.
 * @syntax <code><em>date</em>.toJSON()</code>
 * @returns {Number} 
 */
Date.prototype.toJSON = function() {};

/**
 * Returns the day of the week in the specified date according to universal time.
 * @syntax <code>getUTCDay()</code>
 * @returns {Number} 
 */
Date.prototype.getUTCDay = function() {};

/**
 * Converts a date to a string, using Internet GMT conventioins.
 * @syntax <code>toGMTString()</code>
 * @returns {String} 
 */
Date.prototype.toGMTString = function() {};

/**
 * Returns the milliseconds in the specified date according to universal time.
 * @syntax <code>getUTCMilliseconds()</code>
 * @returns {Number} 
 */
Date.prototype.getUTCMilliseconds = function() {};

/**
 * Returns the milliseconds in the specified date according to local time.
 * @syntax <code>getMilliseconds()</code>
 * @returns {Number} 
 */
Date.prototype.getMilliseconds = function() {};

/**
 * Represents the prototype for the Date constructor.
 * @returns {Number} 
 * @static
 */
Date.prototype;

