/**
 * Every function in JavaScript is actually a Function object.
 * @syntax <code>newFunction([<em>arg1</em>[,<em>arg2</em>[,...<em>argN</em>]],]<em>functionBody</em>)</code>
 * @param {String} arg1,arg2,...argN Names to be used by the function as formal argument names. Each must be a string that corresponds to a valid JavaScript identifier or a list of such strings separated with a comma; for example "x", "theValue", or "a,b".
 * @param {String} functionBody A string containing the JavaScript statements comprising the function definition.
 * @returns {Function} 
 */
function Function() {
    this.prototype
}
/**
 * Returns the function that invoked the specified function. This property is not part of ECMA-262 Edition 3 standard. It is implemented at least in SpiderMonkey (the JavaScript engine used in Mozilla) (see bug 65683 ), V8 (the JavaScript engine used in Chrome) and JScript.
 * @returns {String} 
 */
Function.prototype.caller;

/**
 * Calls a function with a given this value and arguments provided as an array.
 * @syntax <code><em>fun</em>.apply(<em>thisArg</em>[,<em>argsArray</em>])</code>
 * @param {String} thisArg 
 * @param {String}  The value of this provided for the call to fun.  Note that this may not be the actual value seen by the method: if the method is a function in non-strict mode code, null and undefined will be replaced with the global object, and primitive values will be boxed.
 * @param {Array} argsArray An array like object, specifying the arguments with which fun should be called, or null or undefined if no arguments should be provided to the function.
 * @returns {Array} 
 */
Function.prototype.apply = function() {};

/**
 * Calls a function with a given this value and arguments provided individually.
 * @syntax <code><em>fun</em>.call(<em>thisArg</em>[,<em>arg1</em>[,<em>arg2</em>[,...]]])</code>
 * @param {String} thisArg The value of this provided for the call to fun.  Note that this may not be the actual value seen by the method: if the method is a function in non-strict mode code, null and undefined will be replaced with the global object, and primitive values will be boxed.
 * @param {String} arg1,arg2,... Arguments for the object.
 * @returns {String} 
 */
Function.prototype.call = function() {};

/**
 * Returns a string representing the source code for the function.
 * @returns {String} 
 */
Function.prototype.toSource = function() {};

/**
 * Represents the Function prototype object.
 * @returns {Object} 
 * @static
 */
Function.prototype;

/**
 * Specifies the number of arguments expected by the function.
 * @returns {Number} 
 */
Function.prototype.arity;

/**
 * An array-like object corresponding to the arguments passed to a function.
 * @returns {Array} 
 */
Function.prototype.arguments;

/**
 * Determines whether or not a function is a generator.
 * @syntax <code><em>result</em>=<em>fun</em>.isGenerator()</code>
 * @returns {Boolean} 
 */
Function.prototype.isGenerator = function() {};

/**
 * The name of the function.
 * @returns {String} 
 */
Function.prototype.name;

/**
 * Specifies the number of arguments expected by the function.
 * @returns {Number} 
 */
Function.prototype.length;

/**
 * Returns a string representing the source code of the function.
 * @syntax <code><var>function</var>.toString(<var>indentation</var>)</code>
 * @param {String} indentation Non-standard The amount of spaces to indent the string representation of the source code. If indentation is less than or equal to -1, most unnecessary spaces are removed.
 * @returns {String} 
 */
Function.prototype.toString = function() {};

/**
 * Creates a new function that, when called, itself calls this function in the context of the provided this value, with a given sequence of arguments preceding any provided when the new function was called.
 * @syntax <code><em>fun</em>.bind(<em>thisArg</em>[,<em>arg1</em>[,<em>arg2</em>[,...]]])</code>
 * @param {String} thisArgarg1,arg2,... The value to be passed as the this parameter to the target function when the bound function is called.  The value is ignored if the bound function is constructed using the new operator. Arguments to prepend to arguments provided to the bound function when invoking the target function.
 * @returns {String} 
 */
Function.prototype.bind = function() {};

/**
 * Returns a reference to the Function function that created the instance's prototype. Note that the value of this property is a reference to the function itself, not a string containing the function's name.
 * @returns {Function} 
 */
Function.prototype.constructor;

/**
 * Represents the Function prototype object.
 * @returns {Object} 
 * @static
 */
Function.prototype;

