/**
 * Creates a regular expression object for matching text with a pattern.
 * @syntax <code>RegExp(<em>pattern</em><em>[,flags]</em>)</code><br/><code>/<em>pattern</em>/<em>flags</em></code>
 * @param {String} pattern The text of the regular expression.
 * @param {String} flags 
 * @param {String} gim global match ignore case Treat beginning and end characters (^ and $) as working over multiple lines (i.e., match the beginning or end of each line (delimited by \n or \r), not only the very beginning or end of the whole input string)
 * @param {String} y New in Firefox 3 Non-standard sticky; matches only from the index indicated by the lastIndex property of this regular expression in the target string (and does not attempt to match from any later indexes). This allows the match-only-at-start capabilities of the character "^" to effectively be used at any location in a string by changing the value of the lastIndex property.
 * @returns {RegExp} 
 */
function RegExp() {
    this.prototype
}
/**
 * A read/write integer property that specifies the index at which to start the next match. JavaScript 1.5: lastIndex is a property of a RegExp instance, not the RegExp object.
 * @returns {Number} 
 */
RegExp.prototype.lastIndex;

/**
 * Returns a string representing the source code of the object.
 * @syntax <code><em>regexp</em>.toSource()</code>
 * @returns {String} 
 */
RegExp.prototype.toSource = function() {};

/**
 * @returns {Boolean} 
 */
RegExp.prototype.sticky;

/**
 * A read-only property that contains the text of the pattern, excluding the forward slashes. Static JavaScript 1.5: source is a property of a RegExp instance, not the RegExp object.
 * @returns {String} 
 */
RegExp.prototype.source;

/**
 * Executes the search for a match between a regular expression and a specified string. Returns true or false.
 * @syntax <code><em>regexp</em>.test([<em>str</em>])</code>
 * @param {String} regexp The name of the regular expression. It can be a variable name or a literal.
 * @param {String} str The string against which to match the regular expression.
 * @returns {Boolean} 
 */
RegExp.prototype.test = function() {};

/**
 * Reflects whether or not to search in strings across multiple lines. Static JavaScript 1.5: multiline is a property of a RegExp instance, not the RegExp object.
 * @returns {Boolean} 
 */
RegExp.prototype.multiline;

/**
 * Whether or not the "g" flag is used with the regular expression. Read-only JavaScript 1.5: global is a property of a RegExp instance, not the RegExp object.
 * @returns {Boolean} 
 */
RegExp.prototype.global;

/**
 * Returns a string representing the specified object.
 * @syntax <code><em>regexp</em>.toString()</code>
 * @returns {String} 
 */
RegExp.prototype.toString = function() {};

/**
 * Executes a search for a match in a specified string. Returns a result array, or null.
 * @syntax <code><em>result</em>=<em>regexp</em>.exec(<em>str</em>)</code>
 * @param {String} regexp The name of the regular expression. It can be a variable name or a literal.
 * @param {String} str The string against which to match the regular expression.
 * @returns {Array} 
 */
RegExp.prototype.exec = function() {};

/**
 * Whether or not the "i" flag is used with the regular expression. JavaScript 1.5: ignoreCase is a property of a RegExp instance, not the RegExp object.
 * @returns {Boolean} 
 */
RegExp.prototype.ignoreCase;

/**
 * Represents the prototype object for the RegExp constructor.
 * @returns {Object} 
 * @static
 */
RegExp.prototype;

/**
 * Returns a reference to the RegExp function that created the instance's prototype. Note that the value of this property is a reference to the function itself, not a string containing the function's name.
 * @returns {Function} 
 */
RegExp.prototype.constructor;

/**
 * Represents the prototype object for the RegExp constructor.
 * @returns {Object} 
 * @static
 */
RegExp.prototype;

